==> fahrplan_0.0.7.tar.gz: fahrplan-0.0.7/src/main.c <==
/*******************************************************************************

 This file is a part of Fahrplan for maemo 2009-2010

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 ============================================================================
 Name        : main.c
 Author      : smurfy
 Version     : 0.0.5
 Description : Fahrplan application for train lines in Europe
 ============================================================================
 */
/* Includes */
#include "localisation.h"
#include "fahrplan_utils.h"
#include "fahrplan_gui.h"

/**
 * main entry point. mainly init the basics and then calls the initGui function.
 */
int main(int argc, char* argv[]) {

	AppData *data;

	data = g_new0 (AppData, 1);

	locale_init();

	/* Initialize the GTK. */
	gtk_init(&argc, &argv);

	initApplication(data);

	/* Begin the main application */
	gtk_main();

	g_free(data);

	/* Exit */
	return 0;
}

==> fahrplan_0.0.8.tar.gz: fahrplan-0.0.8/src/main.c <==
/*******************************************************************************

 This file is a part of Fahrplan for maemo 2009-2010

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 ============================================================================
 Name        : main.c
 Author      : smurfy
 Version     : 0.0.5
 Description : Fahrplan application for train lines in Europe
 ============================================================================
 */
/* Includes */
#include "localisation.h"
#include "fahrplan_utils.h"
#include "fahrplan_gui.h"

/**
 * main entry point. mainly init the basics and then calls the initGui function.
 */
int main(int argc, char* argv[]) {

	AppData *data;

	data = g_new0 (AppData, 1);

	locale_init();

	osso_context_t *osso_ctx = osso_initialize (APP_NAME, APP_VER, FALSE, NULL);
	g_assert (osso_ctx != NULL);

	/* Initialize the GTK. */
	gtk_init(&argc, &argv);

	initApplication(data);
	
	/* Begin the main application */
	gtk_main();

	osso_deinitialize (osso_ctx); 
	g_free(data);

	/* Exit */
	return 0;
}
